@@ -55,3 +55,10 @@ class SubscriptionRequest(models.Model):
         required=True,
         default=False,
     )
+
+    def get_required_field(self):
+        req_fields = super(SubscriptionRequest, self).get_required_field()
+        req_fields.append('unit_composition')
+        req_fields.append('discovery_channel')
+
+        return req_fields
